@@ -121,17 +121,11 @@ SENTRY_TESTING = True
 SENTRY_SITE = 'example'
 SENTRY_PUBLIC = False
 
-# just to test
-HAYSTACK_SEARCH_ENGINE = 'whoosh'
-
 SENTRY_SEARCH_ENGINE = 'whoosh'
 SENTRY_SEARCH_OPTIONS = {
     'path': os.path.join(PROJECT_ROOT, 'sentry_index'),
 }
 
-# This shouldn't be needed, but bleh
-HAYSTACK_SITECONF = 'sentry.search_indexes'
-
 try:
     import debug_toolbar
 except ImportError, exc:
